@@ -40,29 +40,21 @@ def wkhtmltopdf_bin(
 
     filename = f"wkhtmltopdf_{version}.gz"
     url = f"{REPO}/blob/master/bin/{filename}?raw=true"
-    file_path = HOME / filename
+    gz_path = HOME / filename
     bin_path = final_path / final_name
 
-    print("0.1.6", "----------------------------", "0")
     r = requests.get(url, stream=True)
 
-    print("0.1.6", "----------------------------", "1")
-    with open(file_path, "wb") as f:
+    with open(gz_path, "wb") as f:
         for chunk in r.iter_content(chunk_size=1024):
             if chunk:
                 f.write(chunk)
 
-    print("0.1.6", "----------------------------", "2")
-    if not file_path.is_file():
-        print("Someone -a worker?- had removed your downloaded file!")
-        return
-
-    with gzip.open(file_path, "rb") as f_in:
+    with gzip.open(gz_path, "rb") as f_in:
         with open(bin_path, "wb") as f_out:
             shutil.copyfileobj(f_in, f_out)
 
-    file_path.unlink()
-
+    gz_path.unlink()
     return str(bin_path)
 
 
